function [vn,Vjw] = q2G
d1 = 7; %constant
d2 = 3; %constant
Nch = 3*3^(mod(d1,3)); %given constant; Nch = 9
Bch = 2*pi/Nch; %given constant; Bch ~ 0.698
Wch = mod(1+d2,Nch)*Bch; %given constant; Wch ~ 2.8
Nx = 1 + 100*Nch; %given constant; Nx = 901
Wx = 2*pi/Nx; %given constant; Wx ~ 7e-3

vn = 1:Nx; %the signal to be broadcast
intvn = 1:Nx; %the interrupt signal to be broadcast
Vjw = 1:629; %FT of the signal to be broadcast
intVjw = 1:629; %FT of the interrupt signal to be broadcast

k = 1; %used for the interrupt signal: sin(Wx*n)*exp(1i*(Wch+k*Bch)*n)

for n=1:629 %set all values of Vjw and intVjw to zero
    Vjw(n) = 0;
    intVjw(n) = 0;
end

for n=1:Nx %calculate the shifted signals
    vn(n) = signal(n,Nx,Wx,Wch);
    intvn(n) = intSignal(n,Nx,Wx,Wch,k,Bch);
end

idx = 1;
for w=-pi:.01:pi %run from -pi to pi in steps of .01
    for n=-Nx:Nx
        Vjw(idx) = Vjw(idx) + signal(n,Nx,Wx,Wch)*exp(-1i*w*n); %FT of original signal
        intVjw(idx) = intVjw(idx) + intSignal(n,Nx,Wx,Wch,k,Bch)*exp(-1i*w*n); %FT of interrupt signal
    end
    idx = idx + 1;
end

w=-pi:.01:pi;
subplot(2,2,2); plot(w,Vjw);
title('Fourier Transform of the Broadcast Signal v[n]');
xlabel('frequency [Hz]');
ylabel('V(jw)');
end

function [y] = x(n,Nx,Wx) %original signal to be broadcast: sin(Wx*n)
if n >= 1 && n <= Nx
    y = sin(Wx*n);
else
    y = 0;
end
end

function [y] = signal(n,Nx,Wx,Wch) %multiply x[n] by exp(1i*Wch*n) effectively shifting the signal to Wch
y = x(n,Nx,Wx)*exp(1i*Wch*n);      
end

function [y] = intSignal(n,Nx,Wx,Wch,k,Bch) %multiply x[n] by exp(1i*(Wch+k*Bch)*n) effectively shifting 
y = x(n,Nx,Wx)*exp(1i*(Wch+k*Bch)*n);       % the signal to Wch+k*Bch
end